/*
 * Project name:
     Force click
 * Copyright:
     (c) Mikroelektronika, 2016.
 * Revision History:
     20160523:
       - initial release (AM);
 * Description:
      Example is written to show you how you can use the Force click.
      Pressing the Force surface you are changing the resistance of the click
      ADC results is displayed on the TFT.
 * Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156F.pdf
     Dev.board:       Easypic Fusion v7 -
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.0000MHz
     Ext. Modules:    EasyTFT, Force click
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 * NOTES:
     - Turn on TFT backlight switch SW11.1. (board specific)
     - Place the Force click to the mikroBUS 1

 */
 
#include "resources.h"

// TFT module connections
char TFT_DataPort at LATE;
sbit TFT_RST at LATD7_bit;
sbit TFT_BLED at LATD2_bit;
sbit TFT_RS at LATD9_bit;
sbit TFT_CS at LATD10_bit;
sbit TFT_RD at LATD5_bit;
sbit TFT_WR at LATD4_bit;
char TFT_DataPort_Direction at TRISE;
sbit TFT_RST_Direction at TRISD7_bit;
sbit TFT_BLED_Direction at TRISD2_bit;
sbit TFT_RS_Direction at TRISD9_bit;
sbit TFT_CS_Direction at TRISD10_bit;
sbit TFT_RD_Direction at TRISD5_bit;
sbit TFT_WR_Direction at TRISD4_bit;
// End TFT module connections

// Declare Variables
 char txt[6] = {0};
 unsigned long adc_rd = 0;
 int adc_res,adc_res_old;
 
 const double Vadc_5  = 4.8828125;   // ADC step 5V/1024 4,88mV (10bit ADC)
 const double Vadc_33 = 3.2226562;   // ADC step 3,3V/1024 3,22mV (10bit ADC)
 
// MCU initialization
void Init() 
{
  AD1PCFG = 0xFFEF;                  // Configure AN pins as digital I/O
  TFT_BLED_Direction = 0;            // Set TFT backlight pin as output
  TFT_Set_Default_Mode();
  TFT_Init_ILI9341_8bit(320, 240);   // Initialize TFT display
  TFT_BLED = 1;                      // Turn on TFT backlight
}

//Display Initialization
static void Display_Init()
{
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("Force   Click", 100, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("Force  ADC  [V] :", 40, 110);
}

// Display ADC Value on the screen
void Display_Value()
{
  TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1, CL_WHITE,0,0,0,0);
    FloatToStr(adc_res, &txt);              // Convert adc reading to text string
    txt[5] = 0;                             // Cut all the numbers after the char 5
    TFT_Rectangle(195,50,320,130);
    TFT_Write_Text(txt,200,110);
}

// Read sensor
void ReadSensor() {
  adc_rd = ADC1_Get_Sample(8);              // Read RB8
  delay_ms(10);                             // Pause 10ms
}

// Main
void main() 
{

  ADC1_Init();                   // Initialize ADC module with default settings
  
  Init();
  
  Display_Init();
  
  Delay_ms(500);                // Small delay
  adc_res_old =0;
 
  while (1) 
  {

    ReadSensor();
    Delay_ms(50);

    adc_res = ((double)adc_rd * Vadc_33); // volatage input and resolution
                                          // 3.226 = 3300/1023
    Display_Value();
    adc_res = adc_res_old;

  }
}